---
title: "How does one spell and pronounce pyannote.audio?"
alt_titles:
  - "Why the name of the library?"
  - "Why the logo of the library?"
---

📝 Written in lower case: `pyannote.audio` (or `pyannote` if you are lazy). Not `PyAnnote` nor `PyAnnotate` (sic).
📢 Pronounced like the french verb `pianoter`. `pi` like in `pi`ano, not `py` like in `py`thon.
🎹 `pianoter` means to play the piano (hence the logo 🤯).
